@@ -10,7 +10,7 @@ use constant {
     LP    => 0,
 };
 
-our $VERSION = 1.0;
+our $VERSION = 1.1;
 
 1;
 
@@ -159,28 +159,6 @@ sub insert {
     @{$this->{y}} = ($y_low, $y_high);
 }
 
-sub query_internals {
-    my $this = shift;
-
-    return (
-        $this->{S},
-        $this->{A},
-        $this->{e},
-        $this->{y},
-        $this->{ls},
-    );
-}
-
-sub start_with {
-    my $this = shift;
-
-    $this->{S}  = shift;
-    $this->{A}  = shift;
-    $this->{e}  = shift;
-    $this->{y}  = shift;
-    $this->{ls} = shift;
-}
-
 sub query {
     my $this = shift;
 
@@ -241,15 +219,6 @@ Math::Business::ParabolicSAR - Technical Analysis: Stop and Reversal (aka SAR)
   print "The SAR is long  today.\n" if $sar->long;
   print "The SAR is short today.\n" if $sar->short;
 
-  # You may use this to kick start like this
-  $sar->start_with(@internals);
-
-  # This module keeps track of quite a few more internals than
-  # others in this family, and most of them are useless for
-  # anything besides calculating the next SAR...  Query them like
-  # this:
-  my @internals = $sar->query_internals;
-
 =head1 RESEARCHER
 
 The Parabolic Stop and Reversal was designed by J. Welles Wilder Jr circa 1978.
@@ -273,6 +242,9 @@ please let me know.
 I normally hang out on #perl on freenode, so you can try to get immediate
 gratification there if you like.  L<irc://irc.freenode.net/perl>
 
+There is also a mailing list with very light traffic that you might want to
+join: L<http://groups.google.com/group/stockmonkey/>.
+
 =head1 COPYRIGHT
 
 Copyright (c) 2008 Paul Miller -- LGPL [Software::License::LGPL_2_1]
